django-viter
============

.. image:: https://travis-ci.org/kaleidos/django-viter.png?branch=master
    :target: https://travis-ci.org/kaleidos/django-viter

.. image:: https://coveralls.io/repos/kaleidos/django-viter/badge.png?branch=master
    :target: https://coveralls.io/r/kaleidos/django-viter?branch=master

.. image:: https://pypip.in/v/django-viter/badge.png
    :target: https://crate.io/packages/django-viter

.. image:: https://pypip.in/d/django-viter/badge.png
    :target: https://crate.io/packages/django-viter


Let your users invite other users.

See `code <https://github.com/kaleidos/django-viter>`_ and 
`documentation <http://django-viter.readthedocs.org>`_.

